@@ -1,14 +1,16 @@
 from ngutils.functions import *
 
-__version__ = '0.9.22'
+__version__ = '0.9.23'
 
 __all__ = [
     'accel_steps',
+    'datetime_parse',
     'flatten',
     'hash_hd',
     'host_extract',
     'json_to_list',
     'jupiter_detected',
+    'meta_append',
     'read_files_contents',
     'read_urls_contents',
     'reduce_content',
